@@ -4,7 +4,7 @@ import sys
 from typing import Any, List, Optional
 
 import MeCab
-import word2vec
+from gensim.models import Word2Vec  # type: ignore
 
 
 class AozoraVecMaker():
@@ -24,6 +24,9 @@ class AozoraVecMaker():
         self.novel_dir = os.path.join(self.__pwd__, novel_dir)
         if not os.path.exists(self.novel_dir):
             raise FileExistsError(self.novel_dir)
+        sys.stdout = sys.stderr = open(os.devnull, 'w')
+        self.__tagger = self.__make_tagger()
+        sys.stdout, sys.stderr = sys.__stdout__, sys.__stderr__
 
     def make_model(self, save_modelname: str = 'aozora_model.model') -> None:
         def t(line: str) -> List[Any]:
@@ -42,16 +45,14 @@ class AozoraVecMaker():
                                           for line in novel_text_lines]
             all_novel_lines.extend(tokenized_novel_text_lines)
 
-        model = word2vec.Word2Vec(all_novel_lines, iter=100)  # type: ignore
+        model = Word2Vec(all_novel_lines)
         model.save(os.path.join(self.__pwd__, save_modelname))
 
-    @classmethod
-    def tokenizer(cls, words: str,
+    def tokenizer(self, words: str,
                   part_use: Optional[List[str]] = ['名詞', '形容詞'],
                   normalize_word: bool = True) -> List[Any]:
-        t = cls.__make_tagger()
-        t.parse('')
-        mecab_word_nodes: MeCab.Tagger = t.parseToNode(words)
+        self.__tagger.parse('')
+        mecab_word_nodes: MeCab.Tagger = self.__tagger.parseToNode(words)
         tokenized = []
         while mecab_word_nodes:
             elements = mecab_word_nodes.feature
@@ -61,7 +62,7 @@ class AozoraVecMaker():
                 word = element_list[6]
             part = element_list[0]
 
-            if cls.__is_word(word, part, part_use):
+            if self.__is_word(word, part, part_use):
                 tokenized.append(word)
 
             mecab_word_nodes = mecab_word_nodes.next
@@ -80,9 +81,9 @@ class AozoraVecMaker():
     @staticmethod
     def __make_tagger() -> MeCab.Tagger:
         try:
-            tagger = MeCab.Tagger('-Ochasen')
+            tagger = MeCab.Tagger('')
         except RuntimeError:
-            tagger = MeCab.Tagger('-r/etc/mecabrc -Ochasen')
+            tagger = MeCab.Tagger('-r/etc/mecabrc')
 
         return tagger
 
